ricecooker package
==================

Subpackages
-----------

.. toctree::

    ricecooker.classes
    ricecooker.managers
    ricecooker.utils

Submodules
----------

ricecooker\.chefs module
------------------------

.. automodule:: ricecooker.chefs
    :members:
    :undoc-members:
    :show-inheritance:

ricecooker\.commands module
---------------------------

.. automodule:: ricecooker.commands
    :members:
    :undoc-members:
    :show-inheritance:

ricecooker\.config module
-------------------------

.. automodule:: ricecooker.config
    :members:
    :undoc-members:
    :show-inheritance:

ricecooker\.exceptions module
-----------------------------

.. automodule:: ricecooker.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

ricecooker\.sushi\_bar\_client module
-------------------------------------

.. automodule:: ricecooker.sushi_bar_client
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ricecooker
    :members:
    :undoc-members:
    :show-inheritance:
